summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/VLCInput.h2
-rw-r--r--src/odr-audioenc.cpp (renamed from src/odr-audioencoder.cpp)8
2 files changed, 5 insertions, 5 deletions
diff --git a/src/VLCInput.h b/src/VLCInput.h
index 1d01d66..5ef970b 100644
--- a/src/VLCInput.h
+++ b/src/VLCInput.h
@@ -202,7 +202,7 @@ class VLCInput
/* The thread running process takes samples from m_queue and writes
* them into m_samplequeue. This decouples m_queue from m_samplequeue
- * which is directly used by odr-audioencoder.cpp
+ * which is directly used by odr-audioenc.cpp
*/
void process();
diff --git a/src/odr-audioencoder.cpp b/src/odr-audioenc.cpp
index 80b7ae6..ab5dac2 100644
--- a/src/odr-audioencoder.cpp
+++ b/src/odr-audioenc.cpp
@@ -18,7 +18,7 @@
*/
/*! \mainpage Introduction
* The ODR-mmbTools ODR-AudioEncoder Audio encoder can encode audio for
* ODR-DabMux, both DAB and DAB+. The DAB encoder is based on toolame. The
* DAB+ encoder requires a the Fraunhofer FDK AAC library, with the
* necessary patches for 960-transform to do DAB+ broadcast encoding.
@@ -32,7 +32,7 @@
* The readme for the whole package is \ref md_README
*
* Interesting starting points for the encoder
* - \ref odr-audioencoder.cpp Main encoder file
* - \ref VLCInput.h VLC Input
* - \ref AlsaInput.h Alsa Input
* - \ref JackInput.h JACK Input
@@ -47,7 +47,7 @@
* - \ref mot-encoder.cpp
*
*
- * \file odr-audioencoder.cpp
+ * \file odr-audioenc.cpp
* \brief The main file for the audio encoder
*/
@@ -100,7 +100,7 @@ using namespace std;
void usage(const char* name) {
fprintf(stderr,
- "ODR-AudioEncoder %s is an audio encoder for both DAB and DAB+.\n"
+ "ODR-AudioEnc %s is an audio encoder for both DAB and DAB+.\n"
"The encoder can read from JACK, ALSA or\n"
"a file source and encode to a ZeroMQ output for ODR-DabMux.\n"
"(Experimental!)It can also use libvlc as an input.\n"
@@ -18,7 +18,7 @@
*/
/*! \mainpage Introduction
- * The ODR-mmbTools ODR-AudioEncoder Audio encoder can encode audio for
+ * The ODR-mmbTools ODR-AudioEnc Audio encoder can encode audio for
* ODR-DabMux, both DAB and DAB+. The DAB encoder is based on toolame. The
* DAB+ encoder requires a the Fraunhofer FDK AAC library, with the
@@ -32,7 +32,7 @@
*
* Interesting starting points for the encoder
- * - \ref odr-audioencoder.cpp Main encoder file
+ * - \ref odr-audioenc.cpp Main encoder file
* - \ref VLCInput.h VLC Input
* - \ref AlsaInput.h Alsa Input